/*
 *		Jiri Skala		A01216
 *
 *		KIV / GSVD		2004/05
 */
using System;
using Zcu.Mve.Numerics;

namespace Zcu.Gsvd.DisplaceMap
{
	/// <summary>
	/// <i>Elevation</i> module setup dialog.
	/// </summary>
	public class ElevationSetup : Zcu.Mve.Core.ModuleSetup
	{
		#region Frame components

		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.GroupBox groupBox2;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.NumericUpDown numUpDnX;
		private System.Windows.Forms.NumericUpDown numUpDnY;
		private System.Windows.Forms.NumericUpDown numUpDnZ;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.Label label5;
		private System.Windows.Forms.Label label6;
		private System.Windows.Forms.Button buttonX;
		private System.Windows.Forms.Button buttonY;
		private System.Windows.Forms.Button buttonZ;
		private System.Windows.Forms.RadioButton radioButtonClassic;
		private System.Windows.Forms.RadioButton radioButtonBurn;
		private System.Windows.Forms.RadioButton radioButtonGray;
		private System.Windows.Forms.RadioButton radioButtonXray;
		private System.Windows.Forms.RadioButton radioButtonCopper;
		private System.Windows.Forms.RadioButton radioButtonSepia;
		private System.Windows.Forms.GroupBox groupBox3;
		private System.Windows.Forms.TextBox textBoxColorAttr;
		private System.Windows.Forms.CheckBox checkBoxColorAttr;

		#endregion

		/// <summary>
		/// Reference to module which we set up.
		/// </summary>
		private Elevation parentModule;

		/// <summary>
		/// Constructor. Stores parent module reference, initializes GUI
		/// and loads parent module setup.
		/// </summary>
		/// <param name="parentModule">Parent module reference.</param>
		public ElevationSetup(Elevation parentModule)
		{
			// Required for Windows Form Designer support
			InitializeComponent();

			// store parent module reference
			this.parentModule = parentModule;

			// get elevation vector
			Vector3D elevVect = parentModule.UserElevationVector;
			// set elevation vector components
			numUpDnX.Value = (decimal)elevVect.X;
			numUpDnY.Value = (decimal)elevVect.Y;
			numUpDnZ.Value = (decimal)elevVect.Z;

			// check appropriate color mapping radio button
			switch (parentModule.SelectedColorMapping)
			{
				case ColorMapping.Classic:
					radioButtonClassic.Checked = true;
					break;

				case ColorMapping.Burn:
					radioButtonBurn.Checked = true;
					break;

				case ColorMapping.Gray:
					radioButtonGray.Checked = true;
					break;

				case ColorMapping.Xray:
					radioButtonXray.Checked = true;
					break;

				case ColorMapping.Copper:
					radioButtonCopper.Checked = true;
					break;

				case ColorMapping.Sepia:
					radioButtonSepia.Checked = true;
					break;
			}

			// get color attribute name
			bool shouldBeDefault;
			textBoxColorAttr.Text = parentModule.GetColorAttrName(out shouldBeDefault);
			checkBoxColorAttr.Checked = shouldBeDefault;
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			System.Resources.ResourceManager resources = new System.Resources.ResourceManager(typeof(ElevationSetup));
			this.groupBox1 = new System.Windows.Forms.GroupBox();
			this.buttonZ = new System.Windows.Forms.Button();
			this.buttonY = new System.Windows.Forms.Button();
			this.buttonX = new System.Windows.Forms.Button();
			this.label6 = new System.Windows.Forms.Label();
			this.label5 = new System.Windows.Forms.Label();
			this.label4 = new System.Windows.Forms.Label();
			this.numUpDnZ = new System.Windows.Forms.NumericUpDown();
			this.numUpDnY = new System.Windows.Forms.NumericUpDown();
			this.numUpDnX = new System.Windows.Forms.NumericUpDown();
			this.label3 = new System.Windows.Forms.Label();
			this.label2 = new System.Windows.Forms.Label();
			this.label1 = new System.Windows.Forms.Label();
			this.groupBox2 = new System.Windows.Forms.GroupBox();
			this.radioButtonSepia = new System.Windows.Forms.RadioButton();
			this.radioButtonCopper = new System.Windows.Forms.RadioButton();
			this.radioButtonXray = new System.Windows.Forms.RadioButton();
			this.radioButtonGray = new System.Windows.Forms.RadioButton();
			this.radioButtonBurn = new System.Windows.Forms.RadioButton();
			this.radioButtonClassic = new System.Windows.Forms.RadioButton();
			this.groupBox3 = new System.Windows.Forms.GroupBox();
			this.checkBoxColorAttr = new System.Windows.Forms.CheckBox();
			this.textBoxColorAttr = new System.Windows.Forms.TextBox();
			this.groupBox1.SuspendLayout();
			((System.ComponentModel.ISupportInitialize)(this.numUpDnZ)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.numUpDnY)).BeginInit();
			((System.ComponentModel.ISupportInitialize)(this.numUpDnX)).BeginInit();
			this.groupBox2.SuspendLayout();
			this.groupBox3.SuspendLayout();
			this.SuspendLayout();
			// 
			// groupBox1
			// 
			this.groupBox1.Controls.Add(this.buttonZ);
			this.groupBox1.Controls.Add(this.buttonY);
			this.groupBox1.Controls.Add(this.buttonX);
			this.groupBox1.Controls.Add(this.label6);
			this.groupBox1.Controls.Add(this.label5);
			this.groupBox1.Controls.Add(this.label4);
			this.groupBox1.Controls.Add(this.numUpDnZ);
			this.groupBox1.Controls.Add(this.numUpDnY);
			this.groupBox1.Controls.Add(this.numUpDnX);
			this.groupBox1.Controls.Add(this.label3);
			this.groupBox1.Controls.Add(this.label2);
			this.groupBox1.Controls.Add(this.label1);
			this.groupBox1.Location = new System.Drawing.Point(8, 8);
			this.groupBox1.Name = "groupBox1";
			this.groupBox1.Size = new System.Drawing.Size(264, 176);
			this.groupBox1.TabIndex = 0;
			this.groupBox1.TabStop = false;
			this.groupBox1.Text = "Direction of elevation";
			// 
			// buttonZ
			// 
			this.buttonZ.Location = new System.Drawing.Point(176, 136);
			this.buttonZ.Name = "buttonZ";
			this.buttonZ.Size = new System.Drawing.Size(72, 23);
			this.buttonZ.TabIndex = 12;
			this.buttonZ.Text = "Z axis align";
			this.buttonZ.Click += new System.EventHandler(this.buttonXYZ_Click);
			// 
			// buttonY
			// 
			this.buttonY.Location = new System.Drawing.Point(96, 136);
			this.buttonY.Name = "buttonY";
			this.buttonY.Size = new System.Drawing.Size(72, 23);
			this.buttonY.TabIndex = 11;
			this.buttonY.Text = "Y axis align";
			this.buttonY.Click += new System.EventHandler(this.buttonXYZ_Click);
			// 
			// buttonX
			// 
			this.buttonX.Location = new System.Drawing.Point(16, 136);
			this.buttonX.Name = "buttonX";
			this.buttonX.Size = new System.Drawing.Size(72, 23);
			this.buttonX.TabIndex = 10;
			this.buttonX.Text = "X axis align";
			this.buttonX.Click += new System.EventHandler(this.buttonXYZ_Click);
			// 
			// label6
			// 
			this.label6.Location = new System.Drawing.Point(176, 104);
			this.label6.Name = "label6";
			this.label6.Size = new System.Drawing.Size(16, 23);
			this.label6.TabIndex = 9;
			this.label6.Text = "Z";
			this.label6.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label5
			// 
			this.label5.Location = new System.Drawing.Point(96, 104);
			this.label5.Name = "label5";
			this.label5.Size = new System.Drawing.Size(16, 23);
			this.label5.TabIndex = 8;
			this.label5.Text = "Y";
			this.label5.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label4
			// 
			this.label4.Location = new System.Drawing.Point(16, 104);
			this.label4.Name = "label4";
			this.label4.Size = new System.Drawing.Size(16, 23);
			this.label4.TabIndex = 7;
			this.label4.Text = "X";
			this.label4.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// numUpDnZ
			// 
			this.numUpDnZ.DecimalPlaces = 2;
			this.numUpDnZ.Location = new System.Drawing.Point(192, 104);
			this.numUpDnZ.Minimum = new System.Decimal(new int[] {
																	 100,
																	 0,
																	 0,
																	 -2147483648});
			this.numUpDnZ.Name = "numUpDnZ";
			this.numUpDnZ.Size = new System.Drawing.Size(56, 20);
			this.numUpDnZ.TabIndex = 6;
			// 
			// numUpDnY
			// 
			this.numUpDnY.DecimalPlaces = 2;
			this.numUpDnY.Location = new System.Drawing.Point(112, 104);
			this.numUpDnY.Minimum = new System.Decimal(new int[] {
																	 100,
																	 0,
																	 0,
																	 -2147483648});
			this.numUpDnY.Name = "numUpDnY";
			this.numUpDnY.Size = new System.Drawing.Size(56, 20);
			this.numUpDnY.TabIndex = 5;
			// 
			// numUpDnX
			// 
			this.numUpDnX.DecimalPlaces = 2;
			this.numUpDnX.Location = new System.Drawing.Point(32, 104);
			this.numUpDnX.Minimum = new System.Decimal(new int[] {
																	 100,
																	 0,
																	 0,
																	 -2147483648});
			this.numUpDnX.Name = "numUpDnX";
			this.numUpDnX.Size = new System.Drawing.Size(56, 20);
			this.numUpDnX.TabIndex = 4;
			// 
			// label3
			// 
			this.label3.Location = new System.Drawing.Point(16, 80);
			this.label3.Name = "label3";
			this.label3.Size = new System.Drawing.Size(88, 23);
			this.label3.TabIndex = 2;
			this.label3.Text = "Elevation vector";
			this.label3.TextAlign = System.Drawing.ContentAlignment.MiddleLeft;
			// 
			// label2
			// 
			this.label2.Location = new System.Drawing.Point(16, 56);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(176, 23);
			this.label2.TabIndex = 1;
			this.label2.Text = "Note 2: Vector length is irrelevant.";
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(16, 24);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(240, 32);
			this.label1.TabIndex = 0;
			this.label1.Text = "Note 1: These settings have no effect if there is a vector connected to module in" +
				"put port.";
			// 
			// groupBox2
			// 
			this.groupBox2.Controls.Add(this.radioButtonSepia);
			this.groupBox2.Controls.Add(this.radioButtonCopper);
			this.groupBox2.Controls.Add(this.radioButtonXray);
			this.groupBox2.Controls.Add(this.radioButtonGray);
			this.groupBox2.Controls.Add(this.radioButtonBurn);
			this.groupBox2.Controls.Add(this.radioButtonClassic);
			this.groupBox2.Location = new System.Drawing.Point(8, 256);
			this.groupBox2.Name = "groupBox2";
			this.groupBox2.Size = new System.Drawing.Size(264, 176);
			this.groupBox2.TabIndex = 1;
			this.groupBox2.TabStop = false;
			this.groupBox2.Text = "Color mapping";
			// 
			// radioButtonSepia
			// 
			this.radioButtonSepia.Image = ((System.Drawing.Image)(resources.GetObject("radioButtonSepia.Image")));
			this.radioButtonSepia.ImageAlign = System.Drawing.ContentAlignment.MiddleRight;
			this.radioButtonSepia.Location = new System.Drawing.Point(16, 144);
			this.radioButtonSepia.Name = "radioButtonSepia";
			this.radioButtonSepia.Size = new System.Drawing.Size(232, 24);
			this.radioButtonSepia.TabIndex = 5;
			this.radioButtonSepia.Text = "Sepia";
			// 
			// radioButtonCopper
			// 
			this.radioButtonCopper.Image = ((System.Drawing.Image)(resources.GetObject("radioButtonCopper.Image")));
			this.radioButtonCopper.ImageAlign = System.Drawing.ContentAlignment.MiddleRight;
			this.radioButtonCopper.Location = new System.Drawing.Point(16, 120);
			this.radioButtonCopper.Name = "radioButtonCopper";
			this.radioButtonCopper.Size = new System.Drawing.Size(232, 24);
			this.radioButtonCopper.TabIndex = 4;
			this.radioButtonCopper.Text = "Copper";
			// 
			// radioButtonXray
			// 
			this.radioButtonXray.Image = ((System.Drawing.Image)(resources.GetObject("radioButtonXray.Image")));
			this.radioButtonXray.ImageAlign = System.Drawing.ContentAlignment.MiddleRight;
			this.radioButtonXray.Location = new System.Drawing.Point(16, 96);
			this.radioButtonXray.Name = "radioButtonXray";
			this.radioButtonXray.Size = new System.Drawing.Size(232, 24);
			this.radioButtonXray.TabIndex = 3;
			this.radioButtonXray.Text = "X-ray";
			// 
			// radioButtonGray
			// 
			this.radioButtonGray.Image = ((System.Drawing.Image)(resources.GetObject("radioButtonGray.Image")));
			this.radioButtonGray.ImageAlign = System.Drawing.ContentAlignment.MiddleRight;
			this.radioButtonGray.Location = new System.Drawing.Point(16, 72);
			this.radioButtonGray.Name = "radioButtonGray";
			this.radioButtonGray.Size = new System.Drawing.Size(232, 24);
			this.radioButtonGray.TabIndex = 2;
			this.radioButtonGray.Text = "Grayscale";
			// 
			// radioButtonBurn
			// 
			this.radioButtonBurn.Image = ((System.Drawing.Image)(resources.GetObject("radioButtonBurn.Image")));
			this.radioButtonBurn.ImageAlign = System.Drawing.ContentAlignment.MiddleRight;
			this.radioButtonBurn.Location = new System.Drawing.Point(16, 48);
			this.radioButtonBurn.Name = "radioButtonBurn";
			this.radioButtonBurn.Size = new System.Drawing.Size(232, 24);
			this.radioButtonBurn.TabIndex = 1;
			this.radioButtonBurn.Text = "Burn";
			// 
			// radioButtonClassic
			// 
			this.radioButtonClassic.Image = ((System.Drawing.Image)(resources.GetObject("radioButtonClassic.Image")));
			this.radioButtonClassic.ImageAlign = System.Drawing.ContentAlignment.MiddleRight;
			this.radioButtonClassic.Location = new System.Drawing.Point(16, 24);
			this.radioButtonClassic.Name = "radioButtonClassic";
			this.radioButtonClassic.Size = new System.Drawing.Size(232, 24);
			this.radioButtonClassic.TabIndex = 0;
			this.radioButtonClassic.Text = "Classic";
			// 
			// groupBox3
			// 
			this.groupBox3.Controls.Add(this.checkBoxColorAttr);
			this.groupBox3.Controls.Add(this.textBoxColorAttr);
			this.groupBox3.Location = new System.Drawing.Point(8, 192);
			this.groupBox3.Name = "groupBox3";
			this.groupBox3.Size = new System.Drawing.Size(264, 56);
			this.groupBox3.TabIndex = 2;
			this.groupBox3.TabStop = false;
			this.groupBox3.Text = "Color attribute name";
			// 
			// checkBoxColorAttr
			// 
			this.checkBoxColorAttr.Location = new System.Drawing.Point(120, 24);
			this.checkBoxColorAttr.Name = "checkBoxColorAttr";
			this.checkBoxColorAttr.Size = new System.Drawing.Size(80, 24);
			this.checkBoxColorAttr.TabIndex = 1;
			this.checkBoxColorAttr.Text = "Use default";
			this.checkBoxColorAttr.CheckedChanged += new System.EventHandler(this.checkBoxColorAttr_CheckedChanged);
			// 
			// textBoxColorAttr
			// 
			this.textBoxColorAttr.Location = new System.Drawing.Point(16, 24);
			this.textBoxColorAttr.Name = "textBoxColorAttr";
			this.textBoxColorAttr.Size = new System.Drawing.Size(96, 20);
			this.textBoxColorAttr.TabIndex = 0;
			this.textBoxColorAttr.Text = "textBox1";
			// 
			// ElevationSetup
			// 
			this.Controls.Add(this.groupBox3);
			this.Controls.Add(this.groupBox2);
			this.Controls.Add(this.groupBox1);
			this.Name = "ElevationSetup";
			this.Size = new System.Drawing.Size(280, 440);
			this.groupBox1.ResumeLayout(false);
			((System.ComponentModel.ISupportInitialize)(this.numUpDnZ)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.numUpDnY)).EndInit();
			((System.ComponentModel.ISupportInitialize)(this.numUpDnX)).EndInit();
			this.groupBox2.ResumeLayout(false);
			this.groupBox3.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion

		/// <summary>
		/// Accepts changes and performs parent module setup.
		/// </summary>
		/// <returns>Returns true if setup is correct. Otherwise returns false.</returns>
		public override bool OnOkClick()
		{
			// store elevation vector
			parentModule.UserElevationVector
				= new Vector3D((double)numUpDnX.Value, (double)numUpDnY.Value, (double)numUpDnZ.Value);

			// select color mapping
			if (radioButtonClassic.Checked)
				parentModule.SelectedColorMapping = ColorMapping.Classic;
			else if (radioButtonBurn.Checked)
				parentModule.SelectedColorMapping = ColorMapping.Burn;
			else if (radioButtonGray.Checked)
				parentModule.SelectedColorMapping = ColorMapping.Gray;
			else if (radioButtonXray.Checked)
				parentModule.SelectedColorMapping = ColorMapping.Xray;
			else if (radioButtonCopper.Checked)
				parentModule.SelectedColorMapping = ColorMapping.Copper;
			else
				parentModule.SelectedColorMapping = ColorMapping.Sepia;

			// set color attribute name
			parentModule.SetColorAttrName(textBoxColorAttr.Text, checkBoxColorAttr.Checked);

			return true;
		}

		/// <summary>
		/// Aligns elevation vector to one coordinate system axis.
		/// </summary>
		private void buttonXYZ_Click(object sender, System.EventArgs e)
		{
			// initialize zeros
			decimal x = 0, y = 0, z = 0;

			// set one coordinate to 1
			if (sender.Equals(buttonX))
				x = 1;
			else if (sender.Equals(buttonY))
				y = 1;
			else
				z = 1;

			// assign proper values
			numUpDnX.Value = x;
			numUpDnY.Value = y;
			numUpDnZ.Value = z;
		}

		/// <summary>
		/// Enables / disables default color attribute name.
		/// </summary>
		private void checkBoxColorAttr_CheckedChanged(object sender, System.EventArgs e)
		{
			textBoxColorAttr.Enabled = ! checkBoxColorAttr.Checked;
		}
	}
}