/*
 *		Jiri Skala		A01216
 *
 *		KIV / GSVD		2004/05
 *
 *		INTERNAL TESTING MODULE
 */
using System;
using Zcu.Mve.Core;
using Zcu.Mve.Visualization;

namespace Zcu.Gsvd.DisplaceMap.Testing
{
	/// <summary>
	/// <p>Prints regular 2D grid including all cell and point attributes.
	/// This is internal module for testing purposes only.</p>
	/// </summary>
	[ModuleInfo("Ji Skla", "Prints regular 2D grid including all cell and point "
		+ "attributes. For testing purposes only.")]
	[PortInfo("Input", "Regular 2D grid to print.")]
	public class RegGrid2DWatch : Zcu.Mve.Core.Module
	{
		/// <summary>
		/// Constructor. Creates input port.
		/// </summary>
		public RegGrid2DWatch()
		{
			AddInPort("Input", typeof(RegGrid2D));
		}

		/// <summary>
		/// Prints input regular 2D grid including all cell and point attributes.
		/// </summary>
		public override void Execute()
		{
			// get input grid
			RegGrid2D grid = (RegGrid2D)GetInput("Input");

			// print some basic info
			Console.WriteLine(grid.ToString());

			// check size
			if (grid.Width > 10 || grid.Height > 10)
			{
				Console.WriteLine("Input grid is too big to print.");
				return;
			}

			// print header
			Console.WriteLine("Cell attributes\n----------------");

			// print cell attributes
			foreach (string attrName in grid.GetCellAttrIds())
			{
				// get current attributes
				UniformDataArray2D attr = grid.GetCellAttrs(attrName);

				// print all attributes
				for (int j = 0; j < attr.Height; j++)
				{
					for (int i = 0; i < attr.Width; i++)
						Console.Write(attr[i, j] + "\t");

					Console.WriteLine("");
				}
			}

			// print header
			Console.WriteLine("\nPoint attributes\n----------------");

			// print point attributes
			foreach (string attrName in grid.GetPointAttrIds())
			{
				// get current attributes
				UniformDataArray2D attr = grid.GetPointAttrs(attrName);

				// print all attributes
				for (int j = 0; j < attr.Height; j++)
				{
					for (int i = 0; i < attr.Width; i++)
						Console.Write(attr[i, j] + "\t");

					Console.WriteLine("");
				}
			}
		}
	}
}