/*
 *		Jiri Skala		A01216
 *
 *		KIV / GSVD		2004/05
 *
 *		INTERNAL TESTING MODULE
 */
using System;
using Zcu.Mve.Core;
using Zcu.Mve.Visualization;

namespace Zcu.Gsvd.DisplaceMap.Testing
{
	/// <summary>
	/// <p>Prints triangle mesh including all point attributes.
	/// This is internal module for testing purposes only.</p>
	/// </summary>
	[ModuleInfo("Ji Skla", "Prints triangle mesh including all point attributes. "
		+ "For testing purposes only.")]
	[PortInfo("Input", "Triangle mesh to print.")]
	public class TriMeshWatch : Zcu.Mve.Core.Module
	{
		/// <summary>
		/// Constructor. Creates input port.
		/// </summary>
		public TriMeshWatch()
		{
			AddInPort("Input", typeof(TriangleMesh));
		}

		/// <summary>
		/// Prints input triangle mesh including all point attributes.
		/// </summary>
		public override void Execute()
		{
			// get input triangle mesh
			TriangleMesh mesh = (TriangleMesh)GetInput("Input");

			// print some basic info
			Console.WriteLine(mesh.ToString());

			// check size
			if (mesh.Points.Count > 50)
			{
				Console.WriteLine("Input mesh is too big to print.");
				return;
			}

			// print header
			Console.WriteLine("Triangle mesh points\n--------------------");

			// prepare array for point info
			string[] pointInfo = new string[mesh.Points.Count];

			// store point coordinates
			for (int i = 0; i < pointInfo.Length; i++)
				pointInfo[i] = mesh.Points[i].ToString();

			// store point attributes
			foreach (string attrName in mesh.GetPointAttrsIds())
			{
				// get current attributes
				UniformDataArray attr = mesh.GetPointAttrs(attrName);

				// store all attributes
				for (int i = 0; i < attr.Count; i++)
					pointInfo[i] += "\t" + attr[i];
			}

			// print point info
			for (int i = 0; i < pointInfo.Length; i++)
				Console.WriteLine(pointInfo[i]);
		}
	}
}